Method: Phidgets::Encoder#getPosition

Defined in:
ext/phidgets/phidgets_encoder.c

#getPositionObject Also known as: position

The most recent position value calculated by the Phidgets library. Position counts quadrature edges within a quadrature cycle. This means there are four counts per full quadrature cycle. Position is tracked locally as the total position change from the time the channel is opened. Setting position will only affect the local copy of the position value. This means that positions seen by multiple network applications may not agree.



52
53
54
# File 'ext/phidgets/phidgets_encoder.c', line 52

VALUE ph_encoder_get_position(VALUE self) {
  return ph_get_int64(get_ph_handle(self), (phidget_get_int64_func)PhidgetEncoder_getPosition);
}